@@ -11,6 +11,7 @@
 #include <gdk/gdk.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gdk_Point.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -39,7 +40,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Point_gdk_1point_1free
 }
 
 
-gint32 GdkPoint_get_x (GdkPoint * cptr) 
+static gint32 GdkPoint_get_x (GdkPoint * cptr) 
 {
     return cptr->x;
 }
@@ -54,7 +55,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Point_getX (JNIEnv *env, jclass cls, job
     return (jint) (GdkPoint_get_x (obj_g));
 }
 
-void GdkPoint_set_x (GdkPoint * cptr, gint32 x) 
+static void GdkPoint_set_x (GdkPoint * cptr, gint32 x) 
 {
     cptr->x = x;
 }
@@ -70,7 +71,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Point_setX (JNIEnv *env, jclass cls, job
     GdkPoint_set_x (obj_g, x_g);
 }
 
-gint32 GdkPoint_get_y (GdkPoint * cptr) 
+static gint32 GdkPoint_get_y (GdkPoint * cptr) 
 {
     return cptr->y;
 }
@@ -85,7 +86,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Point_getY (JNIEnv *env, jclass cls, job
     return (jint) (GdkPoint_get_y (obj_g));
 }
 
-void GdkPoint_set_y (GdkPoint * cptr, gint32 y) 
+static void GdkPoint_set_y (GdkPoint * cptr, gint32 y) 
 {
     cptr->y = y;
 }
