@@ -12,12 +12,13 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_Dialog.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-GtkBox * GtkDialog_get_vbox (GtkDialog * cptr) 
+static GtkBox * GtkDialog_get_vbox (GtkDialog * cptr) 
 {
     return (GtkBox*)cptr->vbox;
 }
@@ -32,7 +33,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Dialog_getVbox (JNIEnv *env, jclass c
     return getGObjectHandle(env, (GObject *) GtkDialog_get_vbox (cptr_g));
 }
 
-GtkBox * GtkDialog_get_action_area (GtkDialog * cptr) 
+static GtkBox * GtkDialog_get_action_area (GtkDialog * cptr) 
 {
     return (GtkBox*)cptr->action_area;
 }
