@@ -9,8 +9,10 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
+#include "org_gnu_gtk_IconSet.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -22,7 +24,8 @@ extern "C"
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconSet_gtk_1icon_1set_1new (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gtk_icon_set_new ());
+    return getGBoxedHandle(env, gtk_icon_set_new (), GTK_TYPE_ICON_SET, NULL,
+    		(GBoxedFreeFunc) gtk_icon_set_unref);
 }
 
 /*
@@ -33,18 +36,19 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconSet_gtk_1icon_1set_1new_1from_1pi
     jclass cls, jobject pixbuf) 
 {
     GdkPixbuf *pixbuf_g = (GdkPixbuf *)getPointerFromHandle(env, pixbuf);
-    return getHandleFromPointer(env, gtk_icon_set_new_from_pixbuf (pixbuf_g));
+    return getGBoxedHandle(env, gtk_icon_set_new_from_pixbuf (pixbuf_g),
+    		GTK_TYPE_ICON_SET, NULL, (GBoxedFreeFunc) gtk_icon_set_unref);
 }
 
 /*
  * Class:     org.gnu.gtk.IconSet
  * Method:    gtk_icon_set_ref
  */
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconSet_gtk_1icon_1set_1ref (JNIEnv *env, jclass cls, 
+JNIEXPORT void JNICALL Java_org_gnu_gtk_IconSet_gtk_1icon_1set_1ref (JNIEnv *env, jclass cls, 
     jobject iconSet) 
 {
     GtkIconSet *iconSet_g = (GtkIconSet *)getPointerFromHandle(env, iconSet);
-    return getHandleFromPointer(env, gtk_icon_set_ref (iconSet_g));
+   	gtk_icon_set_ref (iconSet_g);
 }
 
 /*
@@ -58,17 +62,6 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_IconSet_gtk_1icon_1set_1unref (JNIEnv *e
     gtk_icon_set_unref (iconSet_g);
 }
 
-/*
- * Class:     org.gnu.gtk.IconSet
- * Method:    gtk_icon_set_copy
- */
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconSet_gtk_1icon_1set_1copy (JNIEnv *env, jclass cls, 
-    jobject iconSet) 
-{
-    GtkIconSet *iconSet_g = (GtkIconSet *)getPointerFromHandle(env, iconSet);
-    return getHandleFromPointer(env, gtk_icon_set_copy (iconSet_g));
-}
-
 /*
  * Class:     org.gnu.gtk.IconSet
  * Method:    gtk_icon_set_render_icon
@@ -83,7 +76,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconSet_gtk_1icon_1set_1render_1icon
     GtkStateType state_g = (GtkStateType) state;
     GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
     gchar* detail_g = (gchar*)(*env)->GetStringUTFChars(env, detail, 0);
-    jobject result = getHandleFromPointer(env,
+    jobject result = getGObjectHandle(env, (GObject *)
     		gtk_icon_set_render_icon (iconSet_g, style_g, direction_g, state_g, 
             		(GtkIconSize)size, widget_g, detail_g));
     (*env)->ReleaseStringUTFChars(env, detail, detail_g);
@@ -114,7 +107,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_IconSet_gtk_1icon_1set_1get_1sizes (JNIE
     GtkIconSize **sizes_g = (GtkIconSize **)sizes_g_g;
     gint *numSizes_g = (gint *) (*env)->GetIntArrayElements (env, numSizes, NULL);
     gtk_icon_set_get_sizes (iconSet_g, sizes_g, numSizes_g);
-    (*env)->ReleaseIntArrayElements (env, sizes, sizes_g_g, 0);
+    (*env)->ReleaseIntArrayElements (env, sizes, (jint *)sizes_g_g, 0);
     (*env)->ReleaseIntArrayElements (env, numSizes, (jint *) numSizes_g, 0);
 }
 
